@@ -1,6 +1,6 @@
 var searchData=
 [
-  ['wait_0',['wait',['../a00762.html#a9d777609e20094558e76e528c1b15e2e',1,'osl::Condition::wait()'],['../a00878.html#ac51d11d3729116f912934ffefe9ad2d6',1,'osl::Thread::wait()']]],
+  ['wait_0',['wait',['../a00762.html#a9d777609e20094558e76e528c1b15e2e',1,'osl::Condition::wait()'],['../a00878.html#ac51d11d3729116f912934ffefe9ad2d6',1,'osl::Thread::wait()'],['../a00598.html#ac51d11d3729116f912934ffefe9ad2d6',1,'salhelper::Thread::wait()']]],
   ['weak_2ehxx_1',['weak.hxx',['../a00476.html',1,'']]],
   ['weakagg_2ehxx_2',['weakagg.hxx',['../a00479.html',1,'']]],
   ['weakaggcomponentimplhelper1_3',['WeakAggComponentImplHelper1',['../a01050.html',1,'cppu::WeakAggComponentImplHelper1&lt; Ifc1 &gt;'],['../a01050.html#a539345db80771d0ee7e8845f2c022f57',1,'cppu::WeakAggComponentImplHelper1::WeakAggComponentImplHelper1()']]],
@@ -53,7 +53,7 @@ var searchData=
   ['weakimplhelper7_50',['WeakImplHelper7',['../a01738.html',1,'cppu']]],
   ['weakimplhelper8_51',['WeakImplHelper8',['../a01778.html',1,'cppu']]],
   ['weakimplhelper9_52',['WeakImplHelper9',['../a01818.html',1,'cppu']]],
-  ['weakref_2ehxx_53',['weakref.hxx',['../a00482.html',1,'']]],
+  ['weakref_2ehxx_53',['weakref.hxx',['../a00485.html',1,'']]],
   ['weakreference_54',['WeakReference',['../a01958.html',1,'com::sun::star::uno::WeakReference&lt; interface_type &gt;'],['../a01958.html#a81c6ea589549e79c3f826cccee911c96',1,'com::sun::star::uno::WeakReference::WeakReference()'],['../a01958.html#acaf481b6213b80c061daf01407e848c2',1,'com::sun::star::uno::WeakReference::WeakReference(const Reference&lt; interface_type &gt; &amp;rRef)']]],
   ['weakreferencehelper_55',['WeakReferenceHelper',['../a01954.html',1,'com::sun::star::uno::WeakReferenceHelper'],['../a01954.html#aca4edf16679e5f81ed2bef368a4f4d63',1,'com::sun::star::uno::WeakReferenceHelper::WeakReferenceHelper()'],['../a01954.html#a4dee9f907ba07214463819d756726182',1,'com::sun::star::uno::WeakReferenceHelper::WeakReferenceHelper(const WeakReferenceHelper &amp;rWeakRef)'],['../a01954.html#a01c610f0b6dc26c7a66caf6878a51bd5',1,'com::sun::star::uno::WeakReferenceHelper::WeakReferenceHelper(const css::uno::Reference&lt; css::uno::XInterface &gt; &amp;xInt)']]],
   ['which_20fields_20to_20retrieve_20by_20osl_5fgetfilestatus_56',['Flags specifying which fields to retrieve by osl_getFileStatus',['../a00523.html',1,'']]],
